@@ -32,6 +32,11 @@ public class CacheDescriptor {
      */
     public String cacheDirectory = null;
 
+    /**
+     * the lower limit for the size of the volume that should not be occupied by the cache
+     */
+    public long minimumFreeVolumeSize = 0;
+
     /**
      * the upper limit for the size of all persistent files within the cache directory; -1 for no upper limit
      */
