@@ -79,11 +79,18 @@ public class Config {
      */
     public long ENGINE_MAX_VMEM_MB = 2048;
 
+    /**
+     * the minimum size in MegaBytes of the volume, the cache is located on, that will not be used by the cache;
+     */
+    public long ENGINE_MIN_FREE_VOLUMESIZE_MB = 1024;
+
     /**
      * the maximum size in MegaBytes of all persistently cached converter job entries at runtime;
+     * the total cache size will also take into account the value for the minimum free volume size,
+     * so that at least this free volume size will not be occupied by the cache
      * -1 for no upper limit
      */
-    public long ENGINE_MAX_CACHESIZE_MB = 4096;
+    public long ENGINE_MAX_CACHESIZE_MB = -1;
 
     /**
      * the maximum count of converter jobs cached at runtime;
@@ -95,7 +102,7 @@ public class Config {
      * the timeout in seconds, after which a cached job execution result is automatically removed from the cache
      * 0 for disabling the timeout based removal
      */
-    public long ENGINE_CACHEENTRY_TIMEOUT_SECONDS = 86400;
+    public long ENGINE_CACHEENTRY_TIMEOUT_SECONDS = 2592000;
 
     /**
      * Flag to forbid/allow the servlet engine to handle local file:// URLS
