@@ -26,9 +26,9 @@ public interface IJobStatusListener {
 
     /**
      * notifies a registered JobStatusListener that the status of a Job has just changed; the current status of the Job can be retrieved
-     * from the JobProcessor via the given Job id
+     * from the JobProcessor via the given Job id string
      *
-     * @param nJobId
+     * @param jobIdStr
      */
-    public void statusChanged(long nJobId);
+    public void statusChanged(String jobIdStr);
 }
