@@ -59,7 +59,7 @@ public interface IManager {
     public IJob createServerJob(String jobType, HashMap<String, Object> jobProperties, HashMap<String, Object> resultProperties);
 
     /**
-     * @return the instance that offers a UNO interface to the underlying engine backend
+     * @return the instance that offers a UNO interface to the underlying engine backend or null in case of a failure
      */
     public IInstance createServerInstance(BackendType backendType);
 
@@ -67,13 +67,13 @@ public interface IManager {
      * @param jobType The job type fiter to be executed.
      * @param jobProperties Input parameter, containing properties to customize the job (e.g. the InputFile)
      * @param resultProperties Output parameter,  containing additional conversion result properties like e.g. the PageCount of the conversion result.
-     * @return The InputStream with the conversion result in case of success or null.
+     * @return The InputStream with the conversion result in case of success or null in case of a failure
      */
     /**
      * @param jobType
      * @param jobProperties
      * @param resultProperties
-     * @return
+     * @return The InputStream with the conversion result in case of success or null in case of a failure
      */
     public InputStream convert(String jobType, HashMap<String, Object> jobProperties, HashMap<String, Object> resultProperties);
 
@@ -82,29 +82,43 @@ public interface IManager {
      * @param documentInputStream The InputStream, containing the source document to be converted.
      * @param jobProperties Input parameter, containing properties to customize the job (e.g. the InputFile)
      * @param resultProperties Output parameter,  containing additional conversion result properties like e.g. the PageCount of the conversion result.
-     * @return The job id to be used in further getConversionPage/endPageConversion jobs
+     * @return The job id string to be used in further getConversionPage/endPageConversion jobs or null in case of a failure
      */
-    public long beginPageConversion(String jobType, HashMap<String, Object> jobProperties, HashMap<String, Object> resultProperties);
+    public String beginPageConversion(String jobType, HashMap<String, Object> jobProperties, HashMap<String, Object> resultProperties);
 
     /**
-     * @param jobId The job id gotten from a previous call to beginPageConversion
+     * @param jobIdStr The job id gotten from a previous call to beginPageConversion
      * @param pageNumber The number of the page to be returned as input stream.
      * @param pageProperties input/output parameter, containing additional properties to customize the job (input) and containing additional
      *            conversion result properties like e.g. the mime type of the conversion result (output).
-     * @return The stream the converted page can be read from
+     * @return The stream the converted page can be read from or null in case of a failure
      */
-    public InputStream getConversionPage(long jobId, int pageNumber, HashMap<String, Object> resultProperties);
+    public InputStream getConversionPage(String jobIdStr, int pageNumber, HashMap<String, Object> resultProperties);
 
     /**
-     * @param jobId The job id gotten from a previous call to beginPageConversion
+     * @param jobIdStr The job id gotten from a previous call to beginPageConversion
      */
-    public void endPageConversion(long jobId);
+    public void endPageConversion(String jobIdStr);
 
     /**
      * @return the installation path of the underlying DocumentReaderEngine or null if the engine wasn't properly initialized
      */
     public String getEnginePath();
 
+
+    /**
+     * @param svgInputStm The stream to read the SVG file input from
+     * @param targetMimeType The target mime type of the rasterized SVG image; currently support are image/png and image/jpeg [in/out]
+     * @param targetWidth The target width in pixels of the rasterized SVG image [in/out]
+     * @param targetHeight The target height in pixels of the rasterized SVG image [in/out]
+     * @param preserveAspectRatio Use the given targetWidth and targetHeight as bounding rectangle to fit the image extents, preserving the default aspect ratio
+     * @param targetZoomFactor The zoom factor to apply for the rasterized SVG image;
+     *        the zoom factor is applied after any extent set by target width and target height
+     * @return The stream the rasterized SVG image can be read from or null in case of a failure
+     */
+    public InputStream convertSVG(InputStream svgInputStm, String[] targetMimeType, int[] targetPixelWidth, int[] targetPixelHeight, boolean preserveDefaultAspectRatio, float targetZoomFactor);
+
+
     /**
      * @return the created temporary File
      * @param sourceFileName if source document file name is set then the temp file will be created with this file name within a new folder
