@@ -23,33 +23,11 @@ package com.openexchange.documentconverter;
  * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
  */
 public enum JobStatus {
-    /**
- *
- */
     INVALID,
-    /**
- *
- */
-
     NEW,
-    /**
- *
- */
-
     SCHEDULED,
-    /**
- *
- */
-
+    READY,
     RUNNING,
-    /**
- *
- */
-
     FINISHED,
-    /**
- *
- */
-
     ERROR
 }
